============
Introduction
============

.. contents::

Description
===========

Enlarge your plone with the power of leaflet maps.

This integrates the javascripts/css files of leaflet inside the plone relevant registries.

You have an example view at /@@LeafletMapView.

You can look a demo here: `Youtube DEMO <http://www.youtube.com/watch?v=cVOQkhmUffg>`_.

Credits
=======
Companies
---------
|makinacom|_

  * `Planet Makina Corpus <http://www.makina-corpus.org>`_
  * `Contact us <mailto:python@makina-corpus.org>`_

.. |makinacom| image:: http://depot.makina-corpus.org/public/logo.gif
.. _makinacom:  http://www.makina-corpus.com

Authors
-------

- kiorky  <kiorky@cryptelium.net>

Contributors
------------

- Eric BREHAULT <eric.brehault@makina-corpus.com>

